@@ -38,9 +38,12 @@ destroy (HTMLObject *o)
 {
 	HTMLObject *p;
 
-	for (p = HTML_CLUE (o)->head; p != NULL; p = p->next)
+	for (p = HTML_CLUE (o)->head; p != NULL; p = p->next) {
 		html_object_destroy (p);
-
+	}
+	HTML_CLUE (o)->head = NULL;
+	HTML_CLUE (o)->tail = NULL;
+			
 	HTML_OBJECT_CLASS (parent_class)->destroy (o);
 }
 
@@ -296,6 +299,22 @@ save (HTMLObject *self,
 	return TRUE;
 }
 
+static gboolean
+save_plain (HTMLObject *self,
+      HTMLEngineSaveState *state)
+{
+	HTMLObject *p;
+	HTMLClue *clue;
+
+	clue = HTML_CLUE (self);
+
+	for (p = clue->head; p != NULL; p = p->next) {
+		if (! html_object_save_plain (p, state))
+		    return FALSE;
+	}
+
+	return TRUE;
+}
 
 /* HTMLClue methods.  */
 
@@ -395,7 +414,6 @@ html_clue_class_init (HTMLClueClass *klass,
 	object_class->draw = draw;
 	object_class->set_max_ascent = set_max_ascent;
 	object_class->set_max_descent = set_max_descent;
-	object_class->destroy = destroy;
 	object_class->reset = reset;
 	object_class->calc_size = calc_size;
 	object_class->calc_preferred_width = calc_preferred_width;
@@ -405,6 +423,7 @@ html_clue_class_init (HTMLClueClass *klass,
 	object_class->forall = forall;
 	object_class->is_container = is_container;
 	object_class->save = save;
+	object_class->save_plain = save_plain;
 	object_class->search = search;
 
 	/* HTMLClue methods.  */
