@@ -25,12 +25,10 @@
 
 #include "htmlengine.h"
 
-#include "htmlengine-edit-cut.h"
-#include "htmlengine-edit-copy.h"
-
 
 /* Undo/redo.  */
-void  html_engine_undo  (HTMLEngine *e);
-void  html_engine_redo  (HTMLEngine *e);
+void  html_engine_undo      (HTMLEngine *e);
+void  html_engine_redo      (HTMLEngine *e);
+void  html_engine_set_mark  (HTMLEngine *e);
 
 #endif /* _HTMLENGINE_EDIT_H */
