@@ -123,13 +123,13 @@ struct _HTMLObject {
 	guchar flags;
 
 	/* FIXME maybe unify with `flags'?  */
-	gboolean redraw_pending : 1;
-	gboolean selected : 1;
+	guint redraw_pending : 1;
+	guint selected : 1;
 
 	/* If an object has a redraw pending and is being destroyed, this flag
            is set to TRUE instead of g_free()ing the object.  When the draw
            queue is flushed, the g_free() is performed.  */
-	gboolean free_pending : 1;
+	guint free_pending : 1;
 };
 
 struct _HTMLObjectClass {
@@ -242,6 +242,7 @@ struct _HTMLObjectClass {
 	/* Saving.  */
 
 	gboolean (* save) (HTMLObject *self, HTMLEngineSaveState *state);
+	gboolean (* save_plain) (HTMLObject *self, HTMLEngineSaveState *state);
 
 	/* Page splitting (for printing).  */
 
@@ -399,6 +400,9 @@ void        html_object_append_selection_string  (HTMLObject *self,
 gboolean  html_object_save  (HTMLObject          *self,
 			     HTMLEngineSaveState *state);
 
+gboolean  html_object_save_plain  (HTMLObject          *self,
+				   HTMLEngineSaveState *state);
+
 /* set change flag f of this object and of all its parents */
 void  html_object_change_set  (HTMLObject      *self,
 			       HTMLChangeFlags  f);
